# Changelog

## 0.1.0-alpha.8 (2024-07-02)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/Pay-i/pay-i-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** update via SDK Studio ([#28](https://github.com/Pay-i/pay-i-python/issues/28)) ([972e5e3](https://github.com/Pay-i/pay-i-python/commit/972e5e3b8c84df6d3b47ba2dba4137151d9e414c))
* **api:** update via SDK Studio ([#30](https://github.com/Pay-i/pay-i-python/issues/30)) ([3334f89](https://github.com/Pay-i/pay-i-python/commit/3334f89029ba31d70aa759d367be32888a77b603))

## 0.1.0-alpha.7 (2024-07-02)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/Pay-i/pay-i-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** update via SDK Studio ([#23](https://github.com/Pay-i/pay-i-python/issues/23)) ([5c2aa35](https://github.com/Pay-i/pay-i-python/commit/5c2aa35b45c18fb194b4055884d3abded49aad1e))
* **api:** update via SDK Studio ([#25](https://github.com/Pay-i/pay-i-python/issues/25)) ([9712710](https://github.com/Pay-i/pay-i-python/commit/9712710b0ab67462295a3f7531e3b034a91dc094))
* **api:** update via SDK Studio ([#26](https://github.com/Pay-i/pay-i-python/issues/26)) ([eebd44e](https://github.com/Pay-i/pay-i-python/commit/eebd44e55d800da8cf7b9a01108e78a3446d1283))

## 0.1.0-alpha.6 (2024-06-30)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/Pay-i/pay-i-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** update via SDK Studio ([#21](https://github.com/Pay-i/pay-i-python/issues/21)) ([daa4259](https://github.com/Pay-i/pay-i-python/commit/daa4259dc2156dd84843d3264362a6a53ee842c4))

## 0.1.0-alpha.5 (2024-06-28)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/Pay-i/pay-i-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* change ingest bugdet_ids and request_tags from str -&gt; list[str] ([bb70818](https://github.com/Pay-i/pay-i-python/commit/bb7081850e14648db2ad753a0aef461cdd7b1940))
* update types and tests ([02af29a](https://github.com/Pay-i/pay-i-python/commit/02af29aa209c434083c3ea335ccfc80450deda8c))

## 0.1.0-alpha.4 (2024-06-27)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/Pay-i/pay-i-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([#13](https://github.com/Pay-i/pay-i-python/issues/13)) ([c35a02e](https://github.com/Pay-i/pay-i-python/commit/c35a02e163c67c320566bc77fb24bb6cdd8b4bf6))

## 0.1.0-alpha.3 (2024-06-27)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/Pay-i/pay-i-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* fix ([cffc96b](https://github.com/Pay-i/pay-i-python/commit/cffc96b700565b99a9d1b171e7aa820a3a41fb0a))
* test rename of autogenerated parameter name ([53b0e7d](https://github.com/Pay-i/pay-i-python/commit/53b0e7dd2f37573d9683c4aa0c3a86de6d0e3dea))

## 0.1.0-alpha.2 (2024-06-27)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/Pay-i/pay-i-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/Pay-i/pay-i-python/issues/4)) ([08bb37c](https://github.com/Pay-i/pay-i-python/commit/08bb37c7ab580b1c0d6adf12f3745191e9023455))

## 0.1.0-alpha.1 (2024-06-27)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/Pay-i/pay-i-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([ba34638](https://github.com/Pay-i/pay-i-python/commit/ba3463802b7366b450058f6ccdb13419b3bdbfe1))
* **api:** update via SDK Studio ([d87c30c](https://github.com/Pay-i/pay-i-python/commit/d87c30c4d5c3d7dee3a4b96596c8df9e319ca690))
* **api:** update via SDK Studio ([96d12c3](https://github.com/Pay-i/pay-i-python/commit/96d12c3c114642a13469ece184eaec8feee50b1a))
* **api:** update via SDK Studio ([ba169b1](https://github.com/Pay-i/pay-i-python/commit/ba169b1e70894cb2a2f0497e4781121a334716cd))


### Chores

* go live ([#2](https://github.com/Pay-i/pay-i-python/issues/2)) ([81ba939](https://github.com/Pay-i/pay-i-python/commit/81ba93934fc18d2ac642af4ce1a7772996cb5030))
* update SDK settings ([8ff0351](https://github.com/Pay-i/pay-i-python/commit/8ff0351ba46df46381eb41cf4eadf655ddb82049))
* update SDK settings ([441d968](https://github.com/Pay-i/pay-i-python/commit/441d9681112eae338ced67f5186a4a2e371cb99c))
